@@ -309,7 +309,7 @@ void undo_redo_restore (const gchar *action)
                                                                                          decompressor);
 
     g_autoptr(GString) record = g_string_new (NULL);
-    gchar buffer[2];
+    gchar buffer[1];
 
     // The fields that are stored inside an undo file.
     enum { UN_ICON_PATH, UN_MENU_ELEMENT, UN_TYPE, UN_VALUE, UN_MENU_ID, UN_EXECUTE, UN_ELEMENT_VISIBILITY, 
@@ -328,8 +328,8 @@ void undo_redo_restore (const gchar *action)
     guint max_path_depth = 1; // Default value.
 
     // x1E (dec. 30) = record/row separator
-    while (g_input_stream_read (decom_undo_file_input_stream, buffer, 1, NULL, &error) > 0 && !(STREQ (buffer, "\x1E"))) { 
-        g_string_append (record, buffer);
+    while (g_input_stream_read (decom_undo_file_input_stream, buffer, sizeof(buffer), NULL, &error) > 0 && buffer[0] != 0x1E) { 
+        g_string_append_c (record, buffer[0]);
     }
 
     // Global data
@@ -363,9 +363,9 @@ void undo_redo_restore (const gchar *action)
 
     // Menu data
 
-    while (g_input_stream_read (decom_undo_file_input_stream, buffer, 1, NULL, &error) > 0) {
-        if (!(STREQ (buffer, "\x1E"))) { // x1E (dec. 30) = record/row separator
-            g_string_append (record, buffer);
+    while (g_input_stream_read (decom_undo_file_input_stream, buffer, sizeof(buffer), NULL, &error) > 0) {
+        if (buffer[0] != 0x1E) { // x1E (dec. 30) = record/row separator
+            g_string_append_c (record, buffer[0]);
         }
         else { 
             g_auto(GStrv) tokens = g_strsplit (record->str, "\x1F", -1); // x1F (dec. 31) = unit separator
